@@ -44,7 +44,7 @@ SettingsDlg::~SettingsDlg() {}
 
 void SettingsDlg::setupUIPage() {
     //setup UI page
-    TQVBox * page = addVBoxPage( i18n("User Interface"), i18n("User Interface Settings"), DesktopIcon( "window_list") );
+    TQVBox * page = addVBoxPage( i18n("User Interface"), i18n("User Interface Settings"), DesktopIcon( "window_duplicate") );
 
     m_UiWidgets.colorGB = new TQGroupBox( i18n("Color"), page );
     TQGridLayout * colorLayout = new TQGridLayout( m_UiWidgets.colorGB, 3, 3 );
